## dbt-snowflake 1.10.6 - December 19, 2025

### Fixes

- fix issue where incorrect varchar size is applied for iceberg table columns ([#1257](https://github.com/dbt-labs/dbt-adapters/issues/1257))

### Under the Hood

- leverage new expanded_data_type field to avoid impacting downstream use cases for `data_type` ([#1510](https://github.com/dbt-labs/dbt-adapters/issues/1510))
